import os

from django.db import migrations, models

sql_drop_triggers = """
DROP TRIGGER IF EXISTS set_draftinvoice_line_amount_trg ON invoicing_draftinvoiceline;
DROP TRIGGER IF EXISTS set_invoice_line_amount_trg ON invoicing_invoiceline;
"""

with open(
    os.path.join(
        os.path.dirname(os.path.realpath(__file__)),
        '..',
        'sql',
        'invoice_triggers_for_amount.sql',
    )
) as sql_file:
    sql_triggers = sql_file.read()


sql_forwards = sql_triggers


class Migration(migrations.Migration):
    dependencies = [
        ('invoicing', '0058_payment_payer_external_id'),
    ]

    operations = [
        migrations.RunSQL(sql=sql_drop_triggers, reverse_sql=migrations.RunSQL.noop),
        migrations.AddField(
            model_name='draftjournalline',
            name='quantity',
            field=models.IntegerField(default=1),
        ),
        migrations.AddField(
            model_name='draftjournalline',
            name='quantity_type',
            field=models.CharField(
                choices=[('units', 'Units'), ('minutes', 'Minutes')], default='units', max_length=10
            ),
        ),
        migrations.AddField(
            model_name='journalline',
            name='quantity',
            field=models.IntegerField(default=1),
        ),
        migrations.AddField(
            model_name='journalline',
            name='quantity_type',
            field=models.CharField(
                choices=[('units', 'Units'), ('minutes', 'Minutes')], default='units', max_length=10
            ),
        ),
        migrations.AlterField(
            model_name='draftinvoiceline',
            name='quantity',
            field=models.DecimalField(decimal_places=2, max_digits=9),
        ),
        migrations.AlterField(
            model_name='invoiceline',
            name='quantity',
            field=models.DecimalField(decimal_places=2, max_digits=9),
        ),
        migrations.RunSQL(sql=sql_forwards, reverse_sql=migrations.RunSQL.noop),
    ]
